@@ -2,6 +2,14 @@
 #include <gtkmm.h>
 #include <iostream>
 
+Gtk::Dialog* pDialog = 0;
+
+void on_button_clicked()
+{
+  if(pDialog)
+    pDialog->hide(); //hide() will cause main::run() to end.
+}
+
 int main (int argc, char **argv)
 {
   Gtk::Main kit(argc, argv);
@@ -19,7 +27,7 @@ int main (int argc, char **argv)
   }
 
   //Get the Glade-instantiated Dialog:
-  Gtk::Dialog* pDialog = 0;
+  
   refXml->get_widget("DialogBasic", pDialog);
   if(pDialog)
   {
@@ -28,7 +36,7 @@ int main (int argc, char **argv)
     refXml->get_widget("quit_button", pButton);
     if(pButton)
     {
-      pButton->signal_clicked().connect(SigC::slot(*pDialog, &Gtk::Dialog::hide)); //hide() will cause main::run() to end.
+      pButton->signal_clicked().connect( sigc::ptr_fun(on_button_clicked) );
     }
 
     kit.run(*pDialog);
